# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class BoxAdminInline(admin.StackedInline):
    model = models.Box
    extra = 0
    fieldsets = (
        (None, {'fields': (
            'status', 'title', 'body', 'position', 'buttons', 'attrs', 'ordering',
        )}),
    )


class TourAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    list_filter = ('status', 'site', 'language',)
    search_fields = ('title',)
    advanced_search_fields = (
        ('code', 'site',),
        ('title__icontains', 'language',),
    )
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'site', 'title', 'description', 'language', 'info',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('status', 'code', 'site', 'title', 'language', 'ordering')
    list_display_links = ('title',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('language',)
    inlines = (BoxAdminInline,)


class BoxAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    list_filter = ('status', 'tour__site', 'tour__language',)
    search_fields = ('title',)
    advanced_search_fields = (
        ('tour', 'title__icontains',),
        ('tour__language',),
    )
    fieldsets = (
        (_('general information'), {
            'fields': ('tour', 'title', 'body', 'position', 'buttons', 'attrs',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('status', 'tour', 'title', 'ordering')
    list_display_links = ('title',)
    autocomplete_fields = ('tour',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.Tour, TourAdmin)
admin.site.register(models.Box, BoxAdmin)
