# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # TOUR
    def v1_tour_tour_list(self, profile, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_tour_tour_retrieve(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_tour_tour_create(self, profile, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_tour_update(self, profile, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_tour_enable(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_tour_disable(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_tour_destroy(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_tour_tour_get_by_code(self, profile, code, language):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:tour-get-by-code',
            args=(profile, code, language)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    # BOX

    def v1_tour_box_list(self, profile, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_tour_box_retrieve(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_tour_box_create(self, profile, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_box_update(self, profile, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_box_enable(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_box_disable(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_tour_box_destroy(self, profile, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-tour:box-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp
