# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import gettext_lazy as _
from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel
from thx.i18n.models import Language


class Tour(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=255,
        verbose_name=_('code'),
    )
    site = models.URLField(
        verbose_name=_('site'),
    )
    title = models.CharField(
        max_length=255,
        verbose_name=_('title'),
    )
    description = models.TextField(
        blank=True, null=True,
        verbose_name=_('description'),
    )
    language = models.ForeignKey(
        Language,
        on_delete=models.PROTECT,
        related_name='tours',
        verbose_name=_('language'),
    )
    info = models.JSONField(
        blank=True, null=True,
        verbose_name=_('info'),
    )

    class Meta:
        verbose_name = _('tour')
        verbose_name_plural = _('tours')
        ordering = ('ordering', 'title',)
        unique_together = (('code', 'site', 'language',),)
        permissions = (
            ("list_tour", "Can list tour"),
            ("detail_tour", "Can detail tour"),
            ("disable_tour", "Can disable tour"),
        )

    def __str__(self):
        return f"{self.site} {self.title}"


class Box(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    tour = models.ForeignKey(
        Tour,
        on_delete=models.CASCADE,
        related_name='boxes',
        verbose_name=_('tour'),
    )
    title = models.CharField(
        max_length=255,
        verbose_name=_('title'),
    )
    body = models.TextField(
        verbose_name=_('body'),
    )
    position = models.CharField(
        max_length=255,
        verbose_name=_('position'),
    )
    buttons = models.JSONField(
        verbose_name=_('buttons'),
    )
    attrs = models.JSONField(
        blank=True, null=True,
        verbose_name=_('attrs'),
    )

    class Meta:
        verbose_name = _('box')
        verbose_name_plural = _('boxes')
        ordering = ('ordering', 'title')
        permissions = (
            ("list_box", "Can list box"),
            ("detail_box", "Can detail box"),
            ("disable_box", "Can disable box"),
        )

    def __str__(self):
        return f"{self.tour}: {self.title}"
